## Tangent 0.3 Math Formula Search Engine##

*First Released August 2015*

*Authors:*

**Kenny Davila and Richard Zanibbi**,
Rochester Institute of Technology, USA

**Andrew Kane and Frank Tompa**,
University of Waterloo, Canada

-----

Tangent 0.3 is an application designed for indexing and retrieval of math formulas from large collections of documents or web pages. A complete description of our system may be found in our technical report:

[Tangent 0.3 arXiv preprint](http://arxiv.org/abs/1507.06235)



##License##
	LICENSE: Source code, data and results are being released under a Non-Commercial Creative Commons License (see the LICENSE file). 


**Please cite the paper above if you use the source code or data in this repository, and indicate any changes made when code or data are re-released.**




##Package Overview##

This package contains the raw files corresponding to the results reported for automated evaluation in our paper submitted to WSDM 2016. The automated evaluation package contains the following directories:

+ **results** <br /> 
  Set of results from automated evaluation using the arXiv and Wikipedia Datasets. The *automated* experiments show the behavior of the system under different conditions.

##Package Contents##

###Directories: results###

The results from automated evaluation are separated by Dataset in the directories **arXiv** and **Wikipedia**. Each Dataset directory contains (at least) the following sub-directories:

+ **core_output** <br />
  Raw results files produced by the core engine using different system configurations for the NTCIR-11 Wikipedia Task queries. All files are presented in TSV format and they contain the queries with their names and canonical **Symbol Layout Tree (SLT)** string encodings, along with the list of top-100 unique formulas and all the documents that contain each formula. Each file contains raw statistics associated to both the current index and statistics about each query execution. <br />
  
  A naming convention has been adopted to identify the system conditions used to generate each result file. If the file begins with the prefix "EOL" it means that the EOL pairs were active in the core engine. In addition, all files contain the sequence w\_{window\_size}.


+ **reranked_output** <br />
  Results files produced by the re-ranker program after sorting the raw results produced by the core-engine (core\_output directory). While the re-ranking method has been fixed to use the MSS metric, the original set of results retrieved by the core engine will affect the set of formulas included in each file. The same naming conventions and file formats used for the core\_output directory are applied here.  

+ **HTML** (example search engine retrieval pages (SERP) / 'result' pages) <br />
  Examples of the HTML output produced by our system. Results for selected conditions are included in sub-directories that are named with the same convention as the core\_output files, one sub-directory per condition. For each condition, a set of directories with HTML results per query is provided, and these directories are named query\_{query_number}. Each query directory contains 3 HTML files and a sub-directory containing all images used by these 3 files. The HTML files provided per query are:

  + **{query\_name}\_main.html:** Main results file which shows the matching formulas grouped by similar score and same structural matching. Diagrams of substructures that have been matched are provided for each structural group (click on the 'Graphs' button to see these).   
  + **{query\_name}\_docs.html:** Shows the final ranking of documents, considering that each document might contain multiple unique formula matches.
  + **{query\_name}_formulas.html** Extended version of the ranking per formula which shows the complete list of documents that contain each individual formulas. <br />
  
  + The HTML pages contain links which make possible to navigate from each view to any of the other two. *The pages also provide links to the visualization tool which highlights the matched formulas in their original documents. However, These links are broken and will not work under the current directory structure.


+ **summary** <br />
  Contains the summaries of the most important statistics of the system running under different conditions, some of them have also been reported in our paper. The directory contains the following summaries:

  + **core\_times\_queries.csv:** A compilation of core-engine execution times for the NTCIR-11 Wikipedia Task queries under different conditions. The summary contains results from multiple runs in a single file.
  + **index\_generation\_times\_data.csv:** Summary of times required to generate the core-engine index files for each condition.
  + **index\_summary.csv:** Multiple statistics that describe the index content for different indexing parameters.
  + **reranked\_times\_queries.csv:** A compilation of re-ranking execution times for the NTCIR-11 Wikipedia Task queries under different conditions. The summary contains results from multiple runs in a single file.  

In the case of the **Wikipedia** Dataset, there are some additional files provided for the NTCIR-11 Wikipedia Task:

+ **ground\_truth** <br />
  Includes two ground truth files used for the automated benchmark against NTCIR-11 Wikipedia Task. The first file, topic\_groups.csv, contains the classification for each individual query in the Task into four different groups: Easy (E), Variant(V), Frequent (F) and Hard (H). The second file, ground\_truth\_exp.tsv, contains the target formulas for each query including their mathml id and the SLT representation of the target formula. 
  
+ **gold\_standard** <br />
  Contains selected samples of gold standards for queries from the NTCIR-11 Wikipedia Task. A gold standard represents the ideal ordering of all the unique formulas existing in a given Dataset (in this case, the Wikipedia Dataset) for a given query according to a given similarity metric.  The provided queries include the 10 queries used for our human evaluation (see human\_evaluation). All these results have been ranked and group according to our MSS similarity metric. 



+ **mrr** <br />
  Contain the raw success rate and Mean Reciprocal Rank (mrr) results for different conditions (window sizes, with and without EOL pairs). The results provided correspond to the top-100 documents retrieved for each condition (K=100) and to the entire set of documents (K=Inf). The files are named mrr\_{source}\_{filter}\_{group}.txt, where:

     + source: can be either core-engine or re-ranked.
     + filter: can be either unfiltered or filtered. The unfiltered case corresponds to the raw list of documents without any changes. The "formula-centric" evaluation part of the NTCIR-11 Wikipedia Task is computed using the unfiltered list of documents. The filtered case corresponds to the lists where each unique document appears only once (first appearance on the original list). The "document-centric" evaluation part of the NTCIR-11 Wikipedia Task is computed using the "filtered" lists to avoid punishing too hard systems that find multiple matching formulas on irrelevant documents. 
     + group: can be Easy (E), Variant(V), Frequent (F), Hard (H) or All if it includes the four groups. 


